@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -19,12 +17,20 @@ util
 Util methods for functional tests
 """
 import operator
+import os
 
 
 def pick_flavor(flavors):
     """Given a flavor list pick the smallest one."""
     # Enable running functional tests against rax - which requires
     # performance flavors be used for boot from volume
+    flavor_name = os.environ.get('SHADE_FLAVOR')
+    if flavor_name:
+        for flavor in flavors:
+            if flavor.name == flavor_name:
+                return flavor
+        return None
+
     for flavor in sorted(
             flavors,
             key=operator.attrgetter('ram')):
@@ -34,15 +40,3 @@ def pick_flavor(flavors):
             flavors,
             key=operator.attrgetter('ram')):
         return flavor
-
-
-def pick_image(images):
-    for image in images:
-        if image.name.startswith('cirros') and image.name.endswith('-uec'):
-            return image
-    for image in images:
-        if image.name.lower().startswith('ubuntu'):
-            return image
-    for image in images:
-        if image.name.lower().startswith('centos'):
-            return image
